@@ -2,9 +2,6 @@ from os import getenv
 
 from django.conf import settings
 
-# the API HTTP root url
-API_ROOT = "https://api.onfido.com/v2/"
-
 
 def _setting(key, default):
     return getenv(key, default) or getattr(settings, key, default)
@@ -24,22 +21,19 @@ LOG_EVENTS = _setting("ONFIDO_LOG_EVENTS", True)
 # Set to True to bypass request verification (NOT RECOMMENDED)
 TEST_MODE = _setting("ONFIDO_TEST_MODE", False)
 
+# Set to True to expire Checks/Reports that
+# can't be found on the Onfido platform.
+SYNC_DELETION = _setting("ONFIDO_SYNC_DELETION", False)
+
 
 def DEFAULT_REPORT_SCRUBBER(raw):
     """Remove breakdown and properties."""
-    try:
-        del raw["breakdown"]
-        del raw["properties"]
-    except KeyError:
-        pass
-    return raw
+    return {k: v for k, v in raw.items() if k not in ("breakdown", "properties")}
 
 
 def DEFAULT_APPLICANT_SCRUBBER(raw):
     """Remove all personal data."""
-    for k in [k for k in raw.keys() if k not in ("id", "href", "created_at")]:
-        del raw[k]
-    return raw
+    return {k: v for k, v in raw.items() if k in ("id", "href", "created_at")}
 
 
 # functions used to scrub sensitive data from reports
